@@ -440,6 +440,9 @@ class SFLogisticsCreate:
             receiver_region_second = extra_data.get("receiver_region_second", "")
             receiver_region_third = extra_data.get("receiver_region_third", "")
             receiver_address = extra_data.get("receiver_address", "")
+            receiver_name = extra_data.get("receiver_name", "")
+            receiver_email = extra_data.get("receiver_email", "")
+            receiver_phone = extra_data.get("receiver_phone", "")
         else:
             sender_cert_no = ""
             sender_cert_type = ""
@@ -449,6 +452,9 @@ class SFLogisticsCreate:
             receiver_region_second = order.receiver_city
             receiver_region_third = order.receiver_district
             receiver_address = order.receiver_address
+            receiver_name = order.receiver_name
+            receiver_email = order.receiver_email
+            receiver_phone = order.receiver_phone
         payload = {
             "customerCode": SdkConfig.sf_merchant_id,
             "orderOperateType": 1,
@@ -474,6 +480,7 @@ class SFLogisticsCreate:
                 "payMethod": "3",
                 "taxPayMethod": "3",
                 "payMonthCard": SdkConfig.sf_card_no,
+                "taxPayMonthCard": SdkConfig.sf_card_no
             },
             # 寄件人訊息
             "senderInfo": {
@@ -499,7 +506,7 @@ class SFLogisticsCreate:
             # 收件人訊息
             "receiverInfo": {
                 # 寄件人名字
-                "contact": extra_data.get("buyer_name", ""),
+                "contact": receiver_name,
                 # 寄件國家/地區
                 "country": receiver_country,
                 # 郵編
@@ -511,9 +518,9 @@ class SFLogisticsCreate:
                 # 區
                 "regionThird": receiver_region_third,
                 "address": receiver_address,
-                "email": extra_data.get("buyer_email", ""),
+                "email": receiver_email,
                 "cargoType": extra_data.get("cargo_type", 1),
-                "phoneNo": extra_data.get("buyer_phone", ""),
+                "phoneNo": receiver_phone,
             },
             # 包裹訊息
             "parcelInfoList": self.generate_items(order.items),
