@@ -1,5 +1,5 @@
 from datetime import datetime
-from typing import Any, Dict, Optional, Union
+from typing import Any, Dict, Optional, Tuple, Union
 from uuid import uuid4
 
 import boto3
@@ -7,9 +7,15 @@ from fastapi import Request, Response
 from fastapi.responses import HTMLResponse, RedirectResponse
 
 from fastel.cart import Cart
-from fastel.cart.datastructures import InvoiceTypes, PaymentSubTypes
+from fastel.cart.datastructures import (
+    CVSLogisticSubTypes,
+    InvoiceTypes,
+    PaymentSubTypes,
+)
 from fastel.collections import get_collection, get_site_config
 from fastel.config import SdkConfig
+from fastel.exceptions import APIException
+from fastel.logistics.ecpay.models import LogisticsTypes
 from fastel.payment.common.models.callback import CallbackModel
 from fastel.payment.common.models.invoice import InvoiceIssueResp, InvoiceStatus
 from fastel.payment.common.models.order import Checkout, Order
@@ -58,7 +64,9 @@ class NewebpayCheckout:
         self.customer_url = number_url
         self.return_url = redirect_url
 
-    def __call__(self, cart: Cart, **kwargs: Any) -> HTMLResponse:
+    def __call__(
+        self, cart: Cart, return_obj: bool = False, **kwargs: Any
+    ) -> Union[HTMLResponse, Tuple[HTMLResponse, Dict[str, Any]]]:
         checkout_model = self.parse_payload(cart, **kwargs)
         now = default_timestamp()
         checkout_ins = {
@@ -69,19 +77,38 @@ class NewebpayCheckout:
             "attempt": 0,
             "resolved": False,
         }
-        cart.to_checkout(**checkout_ins)
+        checkout_obj = cart.to_checkout(**checkout_ins)
+        if return_obj:
+            return (
+                HTMLResponse(self.gateway.checkout_request(checkout_model)),
+                checkout_obj,
+            )
         return HTMLResponse(self.gateway.checkout_request(checkout_model))
 
     def parse_payload(self, cart: Cart, **kwargs: Any) -> CheckoutModel:
-        type_map = {}
+        type_map: Dict[str, Any] = {}
         if cart.payment_subtype == PaymentSubTypes.credit:
             type_map["CREDIT"] = 1
         elif cart.payment_subtype == PaymentSubTypes.atm:
             type_map["VACC"] = 1
         elif cart.payment_subtype == PaymentSubTypes.linepay:
             type_map["LINEPAY"] = 1
-        elif cart.payment_subtype == PaymentSubTypes.cod:
-            type_map["CVSCOM"] = 1
+        if get_site_config(key="cvs_provider", default="ecpay") == "neweb":
+            if cart.logistics_type == LogisticsTypes.CVS.value:
+                if cart.logistics_subtype == CVSLogisticSubTypes.FAMIC2C.value:
+                    type_map["LgsType"] = "C2C"
+                else:
+                    type_map["LgsType"] = "B2C"
+                if cart.total > 20000 or cart.total < 30:
+                    raise APIException(
+                        status_code=400,
+                        error="validation_error",
+                        detail="物流訂單商品不能超過20000元新台幣或低於30元",
+                    )
+                if cart.payment_subtype == PaymentSubTypes.cod.value:
+                    type_map["CVSCOM"] = 2
+                else:
+                    type_map["CVSCOM"] = 1
 
         return CheckoutModel(
             Amt=cart.total,
@@ -269,8 +296,12 @@ class NewebpayGetNumber:
 
     def respond(self, **kwargs: Any) -> Response:
         order_id = kwargs["order_id"]
+        checkout = get_collection("checkout").find_one({"order_number": order_id})
+        redirect_url = f"{SdkConfig.web_host}/profile/orders/?action=detail&is_created=true&order_number={order_id}"
+        if checkout["owner"].startswith("tmp_"):
+            redirect_url = f"{SdkConfig.web_host}/anonymous/order/?action=detail&is_created=true&order_number={order_id}&tmp_token={checkout['owner']}"
         return RedirectResponse(
-            url=f"{SdkConfig.web_host}/profile/orders?action=detail&is_created=true&order_number={order_id}",
+            url=redirect_url,
             status_code=302,
         )
 
@@ -421,7 +452,9 @@ class EcpayCheckout:
         self.payment_info_url = number_url
         self.order_result_url = redirect_url
 
-    def __call__(self, cart: Cart, **kwargs: Any) -> HTMLResponse:
+    def __call__(
+        self, cart: Cart, return_obj: bool = False, **kwargs: Any
+    ) -> Union[HTMLResponse, Tuple[HTMLResponse, Dict[str, Any]]]:
         checkout_model = self.parse_payload(cart, **kwargs)
         now = default_timestamp()
         checkout_ins = {
@@ -432,7 +465,12 @@ class EcpayCheckout:
             "attempt": 0,
             "resolved": False,
         }
-        cart.to_checkout(**checkout_ins)
+        checkout_obj = cart.to_checkout(**checkout_ins)
+        if return_obj:
+            return (
+                HTMLResponse(self.gateway.checkout_request(checkout_model)),
+                checkout_obj,
+            )
         return HTMLResponse(self.gateway.checkout_request(checkout_model))
 
     @staticmethod
@@ -756,7 +794,9 @@ class LinePayCheckout:
         self.callback_url = callback_url
         self.error_url = error_url
 
-    def __call__(self, cart: Cart, **kwargs: Any) -> Response:
+    def __call__(
+        self, cart: Cart, return_obj: bool = False, **kwargs: Any
+    ) -> Union[Response, Tuple[Response, Dict[str, Any]]]:
         checkout_model = self.parse_payload(cart, **kwargs)
         checkout_resp = self.gateway.checkout_request(checkout_model)
         response = self.parse_gateway_resp(checkout_resp)
@@ -769,7 +809,9 @@ class LinePayCheckout:
             "attempt": 0,
             "resolved": False,
         }
-        cart.to_checkout(**checkout_ins)
+        checkout_obj = cart.to_checkout(**checkout_ins)
+        if return_obj:
+            return response, checkout_obj
         return response
 
     def parse_gateway_resp(self, gateway_resp: LinePayRequestResp) -> Response:
@@ -868,7 +910,7 @@ class LinePayCallback:
     def respond(self, **kwargs: Any) -> Response:
         order_id = kwargs["order_id"]
         return RedirectResponse(
-            url=f"{SdkConfig.web_host}/profile/orders?action=detail&is_created=true&order_number={order_id}",
+            url=f"{SdkConfig.web_host}/profile/orders/?action=detail&is_created=true&order_number={order_id}",
             status_code=302,
         )
 
@@ -912,7 +954,7 @@ def get_checkout_method(
     elif default_payment_provider == "linepay":
         return LinePayCheckout(
             callback_url=f"{SdkConfig.api_host}/{prefix_path}/callback",
-            error_url=f"{SdkConfig.web_host}/misc/error?title=結帳發生錯誤&url={SdkConfig.web_host}&btn_text=返回首頁",
+            error_url=f"{SdkConfig.web_host}/misc/error/?title=結帳發生錯誤&url={SdkConfig.web_host}&btn_text=返回首頁",
         )
 
     raise ValueError("unrecognize payment provider")
@@ -970,8 +1012,14 @@ async def process_redirect(request: Request) -> Response:
     callback_method = get_callback_method()
     data = await callback_method.parse_request(request)
     callback_result = callback_method(data)
+    checkout = get_collection("checkout").find_one(
+        {"order_number": callback_result.order_id}
+    )
+    redirect_url = f"{SdkConfig.web_host}/profile/orders/?action=detail&is_created=true&order_number={callback_result.order_id}"
+    if checkout["owner"].startswith("tmp_"):
+        redirect_url = f"{SdkConfig.web_host}/anonymous/order/?action=detail&is_created=true&order_number={callback_result.order_id}&tmp_token={checkout['owner']}"
     return RedirectResponse(
-        url=f"{SdkConfig.web_host}/profile/orders?action=detail&is_created=true&order_number={callback_result.order_id}",
+        url=redirect_url,
         status_code=302,
     )
 
