@@ -1,6 +1,11 @@
+import time
 from typing import Literal, Optional
 
-from pydantic import BaseModel, EmailStr
+from pydantic import BaseModel, EmailStr, Field
+
+
+def timestamp_generate() -> str:
+    return str(int(time.time()))
 
 
 class CheckoutModel(BaseModel):
@@ -22,13 +27,15 @@ class CheckoutModel(BaseModel):
     BARCODE: Optional[Literal[0, 1]]
     ALIPAY: Optional[Literal[0, 1]]
     P2G: Optional[Literal[0, 1]]
-    CVSCOM: Optional[Literal[0, 1]]
+    CVSCOM: Literal[0, 1, 2, 3] = 0
 
     NotifyURL: Optional[str]
     ReturnURL: Optional[str]
     CustomerURL: Optional[str]
 
     MerchantID: Optional[str]
-    Version: Optional[str] = "1.5"
+    Version: Optional[str] = "2.0"
     RespondType: Optional[str] = "JSON"
-    TimeStamp: Optional[str]
+    TimeStamp: str = Field(default_factory=timestamp_generate)
+
+    LgsType: Literal["B2C", "B2B"] = "B2C"
